Struct State
Source pub struct State {
pub room: String,
pub pos_x: u8,
pub pos_y: u8,
pub avatar: String,
pub palette: String,
pub end: bool,
pub inventory: Inventory,
pub vars: Vars,
pub effect: TextEffect,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.